#!/bin/sh
#######################################################################
#
# Written by Brian White <bcwhite@pobox.com>
# Please contact him first if something is wrong with this script.
# THIS IS JUST AN EXAMPLE.
#
#######################################################################
# This script reads a list of tunnels to create from the config file.
# Simply add a "Connections" line like:
#
# [Tunnel Vision]
# Magic Password = magic-password
# Local Nets = 10.0.1.1/255.255.0.0
# Connections = :1234
#
# to bind and listen on port 1234 or to connect to port 1234 of the
# remote host:
#
# Connections = remotehost:1234
#
# You can also specify multiple connections on a single line like:
#
# Connections = :1234 remote1:1234 remote2:1234 remote3:6245
#
# to listen for incoming connections and bind to three others.
#######################################################################

TV=/usr/sbin/tunnelv
TC=/etc/tunnelv.conf
TL=/var/log/tunnelv
TP=/var/run/tunnelv

test -x $TV || exit 0
test -d $TL || mkdir -m755 $TL
test -e $TC && chmod go= $TC

conf=`egrep ^Connections $TC | sed -e 's/^.*=[  ]//'`

trap "" 1 15


case "$1" in
    start)
        echo -n "Starting secure network tunnels: "
        for host in $conf; do
            echo -n "$host "
            parms=`echo $host | sed -e 's/:/ /g'`
            $TV $parms >/dev/null 2>&1 &
            sleep 3
        done
        echo "."
    ;;

    stop)
        echo -n "Stopping secure network tunnels:"
        killall tunnelv >/dev/null 2>&1
        sleep 5
        echo " ."
    ;;

    restart)
        $0 stop
        $0 start
    ;;

    reload)
    ;;

    force-reload)
        $0 restart
    ;;

    *)
        echo "Usage: $0 {start|stop|reload|restart|force-reload}" >&2
        exit 1
    ;;
esac

exit 0
